@@ -4,8 +4,14 @@ package    # hide from PAUSE
 use base qw(Gearman::Driver::Test::Base::All);
 use Moose;
 
-has 'foo' => (   
-    isa => 'Str',   
+has 'foo' => (
+    isa => 'Str',
+    is  => 'rw',
+    default => 'foo' 
+);
+
+has 'global_foo' => (
+    isa => 'Str',
     is  => 'rw',
     default => 'foo' 
 );
@@ -15,4 +21,9 @@ sub job1 : Job {
     return $self->foo;
 }
 
+sub job2 : Job {
+    my ( $self, $job, $workload ) = @_;
+    return $self->global_foo;
+}
+
 1;
